@@ -7,6 +7,7 @@ OC.L10N.register(
     "No file was uploaded" : "Ingen filer vart lasta opp",
     "Missing a temporary folder" : "Manglar ei mellombels mappe",
     "Cancel" : "Avbryt",
+    "Completed" : "Fullført",
     "Details" : "Detaljar",
     "Sharing" : "Deling",
     "Tags" : "Emneord",
@@ -27,8 +28,9 @@ OC.L10N.register(
     "Update" : "Oppdater",
     "Created:" : "Oppretta:",
     "Description" : "Skildring",
-    "Completed" : "Fullført",
     "seconds ago" : "sekund sidan",
+    "Keyboard shortcuts" : "Tastatursnarvegar",
+    "Search" : "Søk",
     "Shared with you" : "Shared with you",
     "An error occurred" : "Det oppstod ein feil.",
     "Today" : "I dag",
